pub struct Output {
pub outcome: FHIRCode,
}Fields
outcome: FHIRCodeThe subsumption relationship between code/Coding “A” and code/Coding “B”. There are 4 possible codes to be returned (equivalent, subsumes, subsumed-by, and not-subsumed) as defined in the concept-subsumption-outcome value set. If the server is unable to determine the relationship between the codes/Codings, then it returns an error response with an OperationOutcome.