pub struct Input {
pub codeA: Option<FHIRCode>,
pub codeB: Option<FHIRCode>,
pub system: Option<FHIRUri>,
pub version: Option<FHIRString>,
pub codingA: Option<Coding>,
pub codingB: Option<Coding>,
}Fields
codeA: Option<FHIRCode>The “A” code that is to be tested. If a code is provided, a system must be provided
codeB: Option<FHIRCode>The “B” code that is to be tested. If a code is provided, a system must be provided
system: Option<FHIRUri>The code system in which subsumption testing is to be performed. This must be provided unless the operation is invoked on a code system instance
version: Option<FHIRString>The version of the code system, if one was provided in the source data
codingA: Option<Coding>The “A” Coding that is to be tested. The code system does not have to match the specified subsumption code system, but the relationships between the code systems must be well established
codingB: Option<Coding>The “B” Coding that is to be tested. The code system does not have to match the specified subsumption code system, but the relationships between the code systems must be well established